use clap::Parser;

/// GeneIT backend API
#[derive(Parser, Debug, Clone)]
#[clap(author, version, about, long_about = None)]
pub struct AppConfig {
    /// Listen address
    #[clap(short, long, env, default_value = "0.0.0.0:8000")]
    pub listen_address: String,

    /// Website origin
    #[clap(short, long, env, default_value = "http://localhost:3000")]
    pub website_origin: String,

    /// Proxy IP, might end with a star "*"
    #[clap(short, long, env)]
    pub proxy_ip: Option<String>,

    /// PostgreSQL database host
    #[clap(long, env, default_value = "localhost")]
    db_host: String,

    /// PostgreSQL database port
    #[clap(long, env, default_value_t = 5432)]
    db_port: u16,

    /// PostgreSQL username
    #[clap(long, env, default_value = "user")]
    db_username: String,

    /// PostgreSQL password
    #[clap(long, env, default_value = "pass")]
    db_password: String,

    /// PostgreSQL database name
    #[clap(long, env, default_value = "geneit")]
    db_name: String,
}

lazy_static::lazy_static! {
    static ref ARGS: AppConfig = {
        AppConfig::parse()
    };
}

impl AppConfig {
    /// Get parsed command line arguments
    pub fn get() -> &'static AppConfig {
        &ARGS
    }

    /// Get full db connection chain
    pub fn db_connection_chain(&self) -> String {
        format!(
            "postgres://{}:{}@{}:{}/{}",
            self.db_username, self.db_password, self.db_host, self.db_port, self.db_name
        )
    }
}
